﻿using CommunityToolkit.Mvvm.ComponentModel;
using CommunityToolkit.Mvvm.Input;
using System.Diagnostics;
using System.Windows;
using System.Windows.Threading;

namespace CS2ServerOnlineStatus
{
    public partial class NotifyIconViewModel : ObservableObject
    {
        private readonly ServerStatusService _serverService;
        private readonly DispatcherTimer _refreshTimer;

        [ObservableProperty]
        public string statusInfo = "none";

        [ObservableProperty]
        public string serverPlayers = "   Players: ";

        [ObservableProperty]
        public string serverMap = "   Map: ";

        [ObservableProperty]
        public string toolTipText = "Initializing...";

        public NotifyIconViewModel()
        {
            _serverService = new ServerStatusService();
            _refreshTimer = new DispatcherTimer
            {
                Interval = TimeSpan.FromMinutes(_serverService.Settings.RefreshInterval)
            };
            _refreshTimer.Tick += async (s, e) => await Refresh();
            _refreshTimer.Start();
            Task.Run(Refresh); // Initial refresh on startup
        }


        [RelayCommand]
        public async Task Refresh()
        {
            //MessageBox.Show(
            //     $"Server Name: {data.ServerName}\n" +
            //     $"Map: {data.Map}\n" +
            //     $"Game: {data.Game}\n" +
            //     $"Description: {data.Description}\n" +
            //     $"App ID: {data.AppID}\n" +
            //     $"Players: {data.Players}\n" +
            //     $"Max Players: {data.PlayersMax}\n" +
            //     $"Bots: {data.Bots}\n" +
            //     $"Dedicated: {data.Dedicated}\n" +
            //     $"OS: {data.OS}\n" +
            //     $"Password: {data.Password}\n" +
            //     $"VAC: {data.VAC}");

            try
            {
                ServerData data = await _serverService.GetServerDataAsync();

                // Choose what to show in the main class
                StatusInfo = "refreshed at " + DateTime.Now.ToString();
                ServerPlayers = data.Players;
                ServerMap = data.Map;

                // Show tooltip data
                ToolTipText = $"Players: {data.Players}/{data.PlayersMax} | Map: {data.Map}";
            }
            catch (Exception ex)
            {
                ToolTipText = "Error: " + ex.Message;
            }
        }

        [RelayCommand]
        public async Task Connect()
        {
            try
            {
                string resolvedAddress = await _serverService.GetResolvedServerAddressAsync();
                
                Process.Start(
                    new ProcessStartInfo
                    {
                        FileName = "cmd",
                        Arguments = $"/c start steam://connect/{resolvedAddress}:{_serverService.Settings.Port}",
                        CreateNoWindow = true
                    }
                );
            }
            catch (Exception ex)
            {
                ToolTipText = $"Error: {ex.Message}";
                // Uncomment below to show message box for critical errors if desired
                // MessageBox.Show($"Refresh failed: {ex.Message}", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }

        [RelayCommand]
        public void OpenWebSite()
        {
            try
            {
                _serverService.LaunchBrowser("net4all.ru");
            }
            catch (Exception ex)
            {
                ToolTipText = $"Website open failed: {ex.Message}";
            }
        }

        [RelayCommand]
        public void OpenDiscord()
        {
            try
            {
                _serverService.LaunchBrowser("discord.com/app");
            }
            catch (Exception ex)
            {
                ToolTipText = $"Discord open failed: {ex.Message}";
            }
        }

        [RelayCommand]
        public void ListenToMusic()
        {
            try
            {
                _serverService.LaunchBrowser(_serverService.Settings.ListenToMusicUrl);
            }
            catch (Exception ex)
            {
                ToolTipText = $"Music open failed: {ex.Message}";
            }
        }


        [RelayCommand]
        public void ExitApplication()
        {
            _refreshTimer.Stop();
            Application.Current.Shutdown();
        }
    }
}
